from django.apps import apps
from django.http import Http404

from rest_framework.views import APIView
from rest_framework.response import Response


class ListChoiceAPIView(APIView):

    def get_model(self, *args, **kwargs):
        try:
            return apps.get_model(kwargs['app_label'], kwargs['model'])
        except LookupError:
            raise Http404()

    def get_choices(self, *args, **kwargs):
        choices = getattr(self.model, kwargs['choice'], None)

        if choices is None:
            raise Http404()

        return choices

    def format_choice(self, choice):
        return {
            'code': choice[0],
            'description': choice[1],
        }

    def get(self, request, *args, **kwargs):

        self.model = self.get_model(*args, **kwargs)

        choices = self.get_choices(*args, **kwargs)

        data = [self.format_choice(choice) for choice in choices]

        return Response(data)



from setuptools import setup, find_packages

setup(
    name='django-rest-choice',
    packages=find_packages(),
    version='0.0.1',
    license='MIT',
    description='A small library to list django choices with REST_FRAMEWORK',
    author='Marlon Mosquera',
    url='https://github.com/marlonmp/django-rest-choices',
    keywords=['django', 'django_rest', 'choices'],
    install_requires=[
            'django',
            'djangorestframework',
        ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',
    ],
)
